| Title: | Test for Equality of Covariance Matrices |
|---|---|
| Description: | Computes p-values using the largest root test using an approximation to the null distribution by Johnstone (2008) <DOI:10.1214/08-AOS605>. |
| Authors: | Maxime Turgeon [aut, cre] |
| Maintainer: | Maxime Turgeon <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0.9000 |
| Built: | 2026-05-17 05:45:18 UTC |
| Source: | https://github.com/turgeonmaxime/covequal |
Uses Roy's union-intersection principle for testing for equality of covariance matrices between two samples. Also provides p-values.
test_covequal(X, Y, inference = c("TW", "permutation"), nperm)test_covequal(X, Y, inference = c("TW", "permutation"), nperm)
X |
matrix of size n1 x p |
Y |
matrix of size n2 x p |
inference |
Method for computing p-value. |
nperm |
Number of permutations. See details. |
A list containing the test statistic and the p-value.
X <- matrix(rnorm(50*100), ncol = 100) Y <- matrix(rnorm(40*100), ncol = 100) test_covequal(X, Y, inference = "TW", nperm = 10)X <- matrix(rnorm(50*100), ncol = 100) Y <- matrix(rnorm(40*100), ncol = 100) test_covequal(X, Y, inference = "TW", nperm = 10)